==> zio-aws-elasticache_2.12-5.17.104.9-sources.jar: zio/aws/elasticache/model/Endpoint.scala <==
package zio.aws.elasticache.model
import zio.aws.elasticache.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Endpoint(
    address: Option[String] = None,
    port: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.Endpoint = {
    import Endpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.Endpoint
      .builder()
      .optionallyWith(address.map(value => value: java.lang.String))(_.address)
      .optionallyWith(
        port.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.port)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.Endpoint.ReadOnly =
    zio.aws.elasticache.model.Endpoint.wrap(buildAwsValue())
}
object Endpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.Endpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.Endpoint =
      zio.aws.elasticache.model
        .Endpoint(address.map(value => value), port.map(value => value))
    def address: Option[String]
    def port: Option[Integer]
    def getAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("address", address)
    def getPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("port", port)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.Endpoint
  ) extends zio.aws.elasticache.model.Endpoint.ReadOnly {
    override val address: Option[String] =
      scala.Option(impl.address()).map(value => value: String)
    override val port: Option[Integer] = scala
      .Option(impl.port())
      .map(value => zio.aws.elasticache.model.primitives.Integer(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.Endpoint
  ): zio.aws.elasticache.model.Endpoint.ReadOnly = new Wrapper(impl)
}

==> zio-aws-elasticache_2.12-5.17.154.1-sources.jar: zio/aws/elasticache/model/Endpoint.scala <==
package zio.aws.elasticache.model
import zio.aws.elasticache.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Endpoint(
    address: Option[String] = None,
    port: Option[Integer] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.Endpoint = {
    import Endpoint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.Endpoint
      .builder()
      .optionallyWith(address.map(value => value: java.lang.String))(_.address)
      .optionallyWith(port.map(value => value: java.lang.Integer))(_.port)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.Endpoint.ReadOnly =
    zio.aws.elasticache.model.Endpoint.wrap(buildAwsValue())
}
object Endpoint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.Endpoint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.Endpoint =
      zio.aws.elasticache.model
        .Endpoint(address.map(value => value), port.map(value => value))
    def address: Option[String]
    def port: Option[Integer]
    def getAddress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("address", address)
    def getPort: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("port", port)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.Endpoint
  ) extends zio.aws.elasticache.model.Endpoint.ReadOnly {
    override val address: Option[String] =
      scala.Option(impl.address()).map(value => value: String)
    override val port: Option[Integer] =
      scala.Option(impl.port()).map(value => value: Integer)
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.Endpoint
  ): zio.aws.elasticache.model.Endpoint.ReadOnly = new Wrapper(impl)
}
